<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>nový</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>kopie</translation>
    </message>
</context>
<context>
    <name>DrawMapWidget</name>
    <message>
        <source>File error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Každý %1 tah</numerusform>
            <numerusform>Každé %1 tahy</numerusform>
            <numerusform>Každých %1 tahů</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Editovat zbraně</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Nepovolené schéma zbraní</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Editovat schémata</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation>Pokud je tato volba aktivována, výběr herního schématu vybere automaticky i zbraňové schéma</translation>
    </message>
    <message>
        <source>Game Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="obsolete">%1 *** %2 byl odstraněn ze seznamu ignorovaných</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="obsolete">%1 *** %2 byl přidán na seznam ignorovaných</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="obsolete">%1 *** %2 byl odstraněn ze seznamu přátel</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="obsolete">%1 *** %2 byl přidán na seznam přátel</translation>
    </message>
    <message>
        <source>%1 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylesheet imported from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter %1 if you want to use the current StyleSheet in future, enter %2 to reset!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet discarded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save StyleSheet to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid command!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kicking %1 ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>new</source>
        <translation type="obsolete">nový</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Nemohu spustit server</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Nemohu uložit záznam do souboru %1</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Prosím vyberte záznam ze seznamu výše</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>VýchozíTeam</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>Hedgewars Demo Soubor</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>Hedgewars Save Soubor</translation>
    </message>
    <message>
        <source>Demo name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Heslo</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="unfinished">Tvoje přezdívka %1 je
registrovaná na Hedgewars.org
Prosím, zadej své heslo
nebo si v konfiguraci vyber jinou přezdívku:</translation>
    </message>
    <message>
        <source>No password supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished">Přezdívka</translation>
    </message>
    <message>
        <source>Some one already uses
 your nickname %1
on the server.
Please pick another nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No nickname supplied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>cs.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Nemohu otevřít soubor s ukázkou %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Témata</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Malá</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Velká</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Jeskyně</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Šílená</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Malé tunely</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Střední tunely</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Velké tunely</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Malé plovoucí ostrovy</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Střední plovoucí ostrovy</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Velké plovoucí ostrovy</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation>Semínko</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Sada</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Hostující počítač nenalezen. Prosím zkontrolujte jméno hostujícího počítače a nastavení portu.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Spojení odmítnuto</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Místnost zničena</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Důvod odchodu:</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Byl jsi vykopnut</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Heslo</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 se připojil do místnosti</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 se připojil</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 odešel (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 odešel</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="obsolete">Tvoje přezdívka %1 je
registrovaná na Hedgewars.org
Prosím, zadej své heslo
nebo si v konfiguraci vyber jinou přezdívku:</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="obsolete">Přezdívka</translation>
    </message>
    <message>
        <source>User quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf vyhodil chybu v renderování textu, s největší pravděpodobností je to spojeno s chybou ve freetype2. Je doporučeno aktualizovat Vaši freetype knihovnu.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Vyčistit mezipaměť účtů</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Načíst data</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Zpráva serveru pro nejnovějši verzi:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Zpráva serveru pro předchozí verzi:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Číslo protokolu nejnovější verze:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>Motto dne:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Nastavit data</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Připojuji...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Zrušit</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation>Nahrát nakreslenou mapu</translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation type="obsolete">Nakreslené mapy (*.hwmap);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation>Uložit nakreslenou mapu</translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Rozšířené</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Cenu za nejlepší zásah vyhrál &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; body.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaily</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>Graf zdraví</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Hodnocení</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>Cenu za nejlepší zásah vyhrál &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; body.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>Nejlepší zabiják je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; úlovkem za tah.</numerusform>
            <numerusform>Nejlepší zabiják je &lt;b&gt;%1&lt;/b&gt; se &lt;b&gt;%2&lt;/b&gt; úlovky za tah.</numerusform>
            <numerusform>Nejlepší zabiják je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; úlovky za tah.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Celkem  &lt;b&gt;%1&lt;/b&gt; ježek byl zabit toto kolo.</numerusform>
            <numerusform>Celkem  &lt;b&gt;%1&lt;/b&gt; ježci byli zabiti toto kolo.</numerusform>
            <numerusform>Celkem  &lt;b&gt;%1&lt;/b&gt; ježků bylo zabito toto kolo.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 úlovek)</numerusform>
            <numerusform>(%1 úlovky)</numerusform>
            <numerusform>(%1 úlovků)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; si myslel, že je dobré střílet do vlastních ježků s &lt;b&gt;%2&lt;/b&gt; bodem.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; si myslel, že je dobré střílet do vlastních ježků se &lt;b&gt;%2&lt;/b&gt; body.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; si myslel, že je dobré střílet do vlastních ježků s &lt;b&gt;%2&lt;/b&gt; body.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; zabil &lt;b&gt;%2&lt;/b&gt; vlastního ježka.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; zabil &lt;b&gt;%2&lt;/b&gt; vlastní ježky.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; zabil &lt;b&gt;%2&lt;/b&gt; vlastních ježků.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; byl vystrašený a přeskočil tah &lt;b&gt;%2&lt;/b&gt; krát.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; byl vystrašený a přeskočil tah &lt;b&gt;%2&lt;/b&gt; krát.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; byl vystrašený a přeskočil tah &lt;b&gt;%2&lt;/b&gt; krát.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageInGame</name>
    <message>
        <source>In game...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Místní hra (Hra na tomto počítači)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Síťová hra (Hra přes síť)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>Jednoduše zvol stejnou barvu jako spoluhráč, abys hrál ve stejném týmu. Každý z vás bude mít kontrolu nad svými vlastními ježky, ale vyhraje nebo prohraje společně.</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>Některé zbraně mohou způsobovat jen malé poškození, ale mohou být devastující v pravé chvíli. Zkus použít pistoli Desert Eagle ke sražení několika nepřátelských ježků do vody.</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>Pokud si nejsi jistý, co dělat a nechceš plýtvat municí, přeskoč tah. Ale nenech uběhnout moc času, protože pak přijde Náhlá smrt!</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>Pokud chceš zabránit ostatním, aby používali tvoji oblíbenou přezdívku na oficiálním serveru, zaregistruj se na http://www.hedgewars.org/.</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>Jsi znuděn standardní hrou? Vyzkoušej některou misi - nabídnou jiný herní zážitek v závislosti na tom, kterou si vybereš.</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>Standardně hra vždycky nahrává poslední odehraný zápas jako ukázku. Vyber si &apos;Místní hru&apos; a zvol tlačítko &apos;Ukázky&apos; v pravém spodním rohu k jejich přehrávání a správě.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, který jsme vytvořili v našem volném čase. Pokud máš problémy, zeptej se na našem fóru, ale neočekávej prosím nonstop podporu!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, který jsme vytvořili v našem volném čase. Pokud se ti líbí, pomož nám malým příspěvkem, nebo se podílej na práci!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, který jsme vytvořili v našem volném čase. Sdílej ho se svoji rodinou a přáteli dle libosti!</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>Čas od času se konají oficiální turnaje. Nadcházející události budou publikovány na http://www.hedgewars.org/ s několika denním předstihem.</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je k dispozici v mnoha jazycích. Pokud překlad do tvého jazyka vypadá zastaralý nebo chybí, neváhej nás kontaktovat!</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>Hedgewars může být spuštěno na mnoha různých operačních systémech včetně Microsoft Windows, Mac OS X a Linuxu.</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>Vždycky si pamatuj, že můžeš vytvořit vlastní hru na místní síti i internetu. Nejsi odkázán jen na možnost &apos;Prostá hra&apos;.</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>Během hraní bys měl dělat krátké přestávky alespoň jednou za hodinu.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>Pokud tvoje grafická karta nepodporuje hardwarovou akceleraci OpenGL, zkus zapnout nízkou kvalitu pro zlepšení výkonu.</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>Jsme otevřeni návrhům a konstruktivní kritice. Pokud se ti něco nelíbí, nebo máš skvělý nápad, dej nám vědět!</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>Obzvláště při hře online buď slušný a vždy pamatuj na to, že s tebou nebo proti tobě může hrát někdo z nějaké menšiny!</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>Speciální herní módy jako třeba &apos;Vampyrismus&apos; nebo &apos;Karma&apos; ti dovolují vymýšlet úplně jiné herní taktiky. Vyzkoušej je v nějaké hře!</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>Nikdy bys neměl instalovat Hedgewars na počítači, který ti nepatří (škola, univerzita, práce a jiné). Prosím, zeptej se nejprve zodpovědné osoby!</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>Hedgewars mohou být perfektní pro krátkou hru během pauzy. Jen se ujisti, že jsi nepřidal příliš mnoho ježků nebo nezvolil velkou mapu. Zmenšit čas nebo zdraví také urychlí hru.</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>Žádný ježek nebyl zraněn během vytváření této hry.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, který jsme vytvořili v našem volném čase. Pokud ti tuto hru někdo prodal, měl bys chtít vrátit peníze!</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>Připojenim jednoho nebo více gamepadů před začátkem hry ti umožní nastavit je jako ovladač pro tvé týmy.</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>Vytvoř si účet na %1, abys zabránil ostatním používat tvoji oblíbenou přezdívku na oficiálním serveru.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>Pokud tvoje grafická karta nepodporuje hardwarovou akceleraci OpenGL, zkus aktualizovat ovladače.</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation type="unfinished">K dispozici jsou tři různé druhy skoků. Zmáčkni [Vysoký skok] dvakrát, abys udělal skok do větší výšky a dozadu.</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation type="unfinished">Bojíš se pádu z útesu? Stiskni [přesnost], aby ses otočil [vlevo], či [vpravo] bez jakéhokoliv pohybu.</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>Některé zbraně vyžadují speciální strategii, nebo jen spoustu cvičení. Nezavrhuj hned některou zbraň, pokud jednou mineš cíl.</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation>Většina zbraní nefunguje, jakmile se ponoří do vody. Naváděná včela nebo dort jsou vyjímka z tohoto pravidla.</translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>Olomoucké tvarůžky vybuchují jen málo, ale vítr ovlivňuje oblak smradu, který může nakazit mnoho ježků najednou.</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>Útok pianem je nejničivější letecký útok. Na druhé straně ale ztratíš ježka, který tento útok vykoná.</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>Přisavné miny jsou perfektní nástroj na vytváření malých řetězových reakcí, které mohou nepřátelské ježky dostat do divokých situací ... nebo vody.</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>Kladivo je nejefektivnější při použitǐ na mostech a traverzách. Zasažený ježek prostě prorazí skrz zem.</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>Pokud jsi zaseklý za nepřátelským ježkem, použij kladivo, aby ses osvobodil a nemusel riskovat zranění z exploze.</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>Maximální vzdálenost, do které dort dojde, je ovlivněna terénem, kterým musí jít. Použij [útok] k dřívější explozi.</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>Plamenomet je zbraň, ale dá se použít i pro kopání tunelů.</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>Chceš vědět, kdo stojí za touto hrou? Klikni na logo Hedgewars v hlavním menu a podívej se.</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation>Líbí se ti Hedgewars? Staň se fanouškem na %1 nebo nás sleduj na %2!</translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>Neboj se kreslit vlastní hroby, čepice, vlajky nebo mapy a témata! Ale pamatuj, že je musíš někde sdílet, abys je mohl používat online.</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>Opravdu chceš nosit specifickou čepici? Daruj nám něco a dostaneš exklusivní čepici dle svého výběru!</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>Udržuj ovladače grafické karty aktuální, aby ses vyhnul problémům při hře.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished">Své nastavení Hedgewars najdeš v &quot;Dokumenty\Hedgewars&quot;. Vytvoř si zálohu nebo si je přenášej s sebou, ale needituj je ručně.</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation>Můžeš si asociovat Hedgewars soubory (uložené hry a nahrávky) tak, abys je mohl ihned spouštět z internetového prohlížeče nebo prúzkumníka souborů.</translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation>Chceš ušetřit lana? Uvolni ho ve vzduchu a vystřel znovu. Dokud se nedotkneš země, využíváš ho bez plýtvání munice!</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished">Konfigurace Hedgewars je k nalezení ve tvém domovském adresáři pod &quot;Library/Application Support/Hedgewars&quot;. Vytvoř si zálohu, přenášej ho s sebou, ale neměň ho ručně.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished">Konfigurace Hedgewars je k nalezení ve tvém domovském adresáři pod &quot;.hedgewars&quot;. Vytvoř si zálohu, přenášej ho s sebou, ale neměň ho ručně.</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation>Windows verze Hedgewars podporuje Xfire. Přidej si Hedgewars do jeho seznamu her, abys viděl přátele, kteří ho hrají.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. Its turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Naváděná včela může být obtížná na použití. Její poloměr otáčení je závislý na její rychlosti, zkus ji nepoužívat při plné síle.</translation>
    </message>
    <message>
        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation>Použij Molotov nebo plamenomet, abys dočasně zamezil ježkům v přechodu terénu jako jsou tunely nebo plošiny.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloadable Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Prosím vyberte server ze seznamu výše</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Ovládání</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Chyba</translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation type="unfinished">Prosím zadejte jméno místnosti</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Hra po místní síti</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Oficiální server</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nový tým</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Upravit tým</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Smazat tým</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>Nemůžeš upravovat týmy z výběru týmu. Vrať se do hlavní nabídky, kde můžeš přidávat, upravovat a mazat týmy.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation>Nové schéma</translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation>Upravit schéma</translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation>Smazat schéma</translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation>Nový sada zbraní</translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation>Upravit sadu zbraní</translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation>Smazat sadu zbraní</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Přejmenovávací dialog</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Zadejte jméno nového souboru:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Nemohu přejmenovat na</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Nemohu smazat soubor</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Prosím vyberte záznam ze seznamu</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Připojit se</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Možnosti správce</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Jméno místnosti:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Tato hra je v čekárně.
Můžeš se přidat a začít hrát, jakmile hra začne.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Tato hra právě probíhá.
Můžeš se přidat a pozorovat, ale musíš počkat, než hra skončí, jestli chceš začít hrát.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 je hostitel. On může nastavovat a odstartovat hru.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Náhodná mapa</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Hra může být hrána na předem vytvořené nebo na náhodné mapě.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Herní schéma definuje obecné možnosti a nastavení jako třeba počet kol, náhlou smrt nebo vampyrismus.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Zbraňové schéma definuje zbraně, které budou k dispozici a jejich munici.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>V místnosti je %1 připojený klient.</numerusform>
            <numerusform>V místnosti jsou %1 připojení klienti.</numerusform>
            <numerusform>V místnosti je %1 připojených klientů.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>V místnosti je %1 účastnící se tým.</numerusform>
            <numerusform>V místnosti jsou %1 účastnící se týmy.</numerusform>
            <numerusform>V místnosti je %1 účastnících se týmů.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Prosím zadejte jméno místnosti</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Prosím vyberte místnost ze seznamu</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Náhodný labyrint</translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="obsolete">Stav:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Pravidla:</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Zbraně:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Hledej:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vyčisti</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Pozor</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>Hra, do které se snažíš připojit, začala.
Ještě stále se chceš připojit do místosti?</translation>
    </message>
    <message numerus="yes">
        <source>%1 players online</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>Nové</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Braň svou pevnoust a znič protivníky, dvě barvy týmů maximálně!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Týmy startují na opačných stranách terénu, dvě barvy týmů maximálně!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Krajina nejde zničit!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="obsolete">Přidá nezničitelnou hranici okolo terénu</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Nižší gravitace</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Podpora míření pomocí laserového mířidla</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Všichni ježci mají osobní silové pole</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Získej zpět 80% z poškození, které učiníš</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Sdílej protivníkovu bolest, sdílej jeho poškození</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Tvoji ježci se nemohou hýbat, prozkoušej své dělostřelecké dovednosti</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Náhodné</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Vteřiny</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Pořadí hraní je náhodné, nikoliv podle pořadí v místnosti.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Hraj s králem. Pokud zemře on, tvoje strana zemře.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Získej tah na úmistění ježků před začátkem hry.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Munice je sdílená mezi týmy se stejnou barvou.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Vypni traverzy při generování náhodné mapy.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Vypni teréní objekty při generování náhodné mapy.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>Počítač se po smrti obnoví.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>Všichni (žijící) ježci jsou plně uzdraveni na konci tahu</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>Útočení neukončí tah.</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>Zbraně jsou obnoveny na startovní hodnoty každý tah.</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>Každý ježek má svou vlastní munici. Nesdílí ji s týmem.</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation>Nemusíš se už starat o vítr.</translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation>Vítr bude ovlivňovat téměř všechno.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopie</translation>
    </message>
    <message>
        <source>Teams in each clan take successive turns sharing their turn time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructible border around the terrain</source>
        <translation>Přidá nezničitelnou hranici okolo terénu</translation>
    </message>
    <message>
        <source>Add an indestructible border along the bottom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopie</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Prostá hra (rychlá hra proti počítači, nastavení je zvoleno)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Hra více hráčů (hrát na jednom počítači proti přátelům nebo počítači)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation type="obsolete">Výcvikový mód (Procvič si schopnosti v řadě tréningových misí). VE VÝVOJI</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Ukázky (Sledování nahraných her)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Nahrát (Nahrát uloženou hru)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation type="obsolete">Mód tažení (...). VE VÝVOJI</translation>
    </message>
    <message>
        <source>Campaign Mode (...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageTraining</name>
    <message>
        <source>No description available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a mission!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Vyhodit</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Omezit připojení</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Omezit přidávání týmů</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Zákaz</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Sledovat</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovat</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Přidat přítele</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Přestat ignorovat</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Odstranit přítele</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Obnovit</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Zkontrolovat při startu novou verzi</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Celá obrazovka v menu</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Zapnout zvuky</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Zapnout hudbu</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Zobrazovat FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Zobrazovat částečná zranění</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Připojit datum a čas k jménu záznamu</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Ukazovat tipy ke zbraním</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Zapnout zvuky v menu</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Zapnout hudbu v menu</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Efekty v menu</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>generovaná mapa...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Člověk</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Úrověň</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Podle systému)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>generovaný labyrint...</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Mise</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Komunita</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Jakékoliv</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>V čekárně</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>Probíhá</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Základní</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation>ručně kreslená mapa...</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Red/Cyan</source>
        <translation>Červená/Azurová</translation>
    </message>
    <message>
        <source>Cyan/Red</source>
        <translation>Azurová/Červená</translation>
    </message>
    <message>
        <source>Red/Blue</source>
        <translation>Červená/Modrá</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Modrá/Červená</translation>
    </message>
    <message>
        <source>Red/Green</source>
        <translation>Červená/Zelená</translation>
    </message>
    <message>
        <source>Green/Red</source>
        <translation>Zelená/Červená</translation>
    </message>
    <message>
        <source>Side-by-side</source>
        <translation type="unfinished">Bok-po-boku</translation>
    </message>
    <message>
        <source>Top-Bottom</source>
        <translation type="unfinished">Shora-Dolu</translation>
    </message>
    <message>
        <source>Wiggle</source>
        <translation type="unfinished">Kývat se</translation>
    </message>
    <message>
        <source>Red/Cyan grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Členové týmu</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Pevnost</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Nastavení kláves</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Týmy</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Zbraně</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Nastavení audio/video</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Síťová hra</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Hrající týmy</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Herní modifikátory</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Základní nastavení</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Týmová nastavení</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Ostatní</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation>Schémata a zbraně</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation type="obsolete">Tento program je poskytovaný pod GNU General Public licencí</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Vývojáři:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafika:</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Zvuky:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Překlady:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Speciální poděkování:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbraně</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hostitelský počítač:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Síťová přezdívka</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rozlišení</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS limit</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Počáteční hlasitost</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Jméno serveru:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Port serveru:</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Modifikátor poškození</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Čas tahu</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Počáteční zdraví</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Čas do náhlé smrti</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>Časovač min</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Počet min</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Jméno schématu:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Shazování beden</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Herní schéma</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% falešných min</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Hrob</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Vlajka</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Hlas</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Aby se nastavení použilo, restartuj hru</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Výbušniny</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Tip: </translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Tato vývojová verze je &apos;v průběhu práce&apos; a může být kompatibilní s jinými verzemi hry. Některé možnosti mohou být rozbité nebo nekompletní. Používej na vlastní riziko!</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% zdravotních beden</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>Zdraví v bedně</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>Zvyšování hladiny</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>Snižování života</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation>% délky lana</translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation type="obsolete">Hra</translation>
    </message>
    <message>
        <source>Stereo rendering</source>
        <translation type="unfinished">Duální vykreslování</translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Heslo</translation>
    </message>
    <message>
        <source>% Get Away Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License v2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>nepojmenovaný</translation>
    </message>
    <message>
        <source>hedgehog %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Síť</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Spojení se serverem ztraceno</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Chyba při otevírání adresáře s daty:
%1
Prosím zkontorlujte vaši instalaci</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbraně</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Nemohu editovat základní nastavení zbraní</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Nemohu smazat základní nastavení zbraní</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Opravdu smazat toto nastavení zbraní?</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>Nemohu přepsat výchozí sadu zbraní &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>Všechny asociace souborů byly nastaveny.</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>Asociace souborů selhala.</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Týmy</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation>Opravdu smazat tento tým?</translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation>Schémata</translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation>Nemohu smazat výchozí schéma &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation>Opravdu smazat toto herní schéma?</translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation>Nemohu smazat výchozí sadu zbraní &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Nemohu vytvořit adresář %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Přezdívka</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Prosím zadej svou přezdívku</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation>základní</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Spusť server</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Připojit</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Upřesnit</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Připraven</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Jedem!</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Přehrát záznam</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Nahrát</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Náhodný tým</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>Asociovat přípony souborů</translation>
    </message>
    <message>
        <source>more</source>
        <translation>více</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Jméno místnosti</translation>
    </message>
    <message>
        <source>C</source>
        <translation>K</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Vlastník</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Pravidla</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbraně</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Sada zbraní</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Pravděpodobnosti</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Munice v bednách</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Prodlevy</translation>
    </message>
    <message>
        <source>new</source>
        <translation>nový</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>kopie</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Nemohu spustit server: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Nemohu spustit engine: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampyrismus</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Dělostřelectvo</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Pevnosti</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Rozděl týmy</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Pevná zem</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Přidej hranice</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Nízká gravitace</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Laserové zaměřování</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Nesmrtelnost</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Náhodné pořadí</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Král</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Umísti ježky</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Klan sdílí munici</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Vypni traverzy</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Vypni teréní objekty</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation type="unfinished">Mód &apos;Počítač přežívá&apos;</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>Obnova zdraví</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>Neomezeně útoků</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>Obnova zbraní</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>Individuální munice</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation>Vypni vítr</translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation>Více větru</translation>
    </message>
    <message>
        <source>Tag Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bottom Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>nahoru</translation>
    </message>
    <message>
        <source>left</source>
        <translation>doleva</translation>
    </message>
    <message>
        <source>right</source>
        <translation>doprava</translation>
    </message>
    <message>
        <source>down</source>
        <translation>dolů</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>útok</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>přesné míření</translation>
    </message>
    <message>
        <source>put</source>
        <translation>položit</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>přepnout</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>najít ježka</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>menu zbraní</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>pozice 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>pozice 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>pozice 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>pozice 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>pozice 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>pozice 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>pozice 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>pozice 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>pozice 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>časovač 1 vt</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>časovač 2 vt</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>časovač 3 vt</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>časovač 4 vt</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>časovač 5 vt</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>rozhovor</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>historie rozhovoru</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pauza</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>potvrzení</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>zeslabit</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>zesílit</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>změnit režim</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>sejmout</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>info o ježkovi</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>ukončit</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>přiblížit</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>oddálit</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>obnovit přiblížení</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>dlouhý skok</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>vysoký skok</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>pozice 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Základní ovládání</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Ovládání zbraní</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Ovládání kamery a kurzoru</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Pohybuj ježkem a miř:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Překonej mezery a překážky skokem:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Odpal zvolenou zbraň nebo použij nástroj:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Vyber zbraň nebo cílové místo pod kurzorem:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Přepni aktivního ježka (pokud je to možné):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Vyber zbraň nebo nástroj:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Nastav časovač bomby nebo časované zbraně:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Pohni kamerou na aktivního ježka:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Pohni kurzorem nebo kamerou bez použití myši:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Změň přiblížení kamery:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Mluv ke svému týmu nebo všem účastníkům:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pozastav, pokračuj nebo opusť hru:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Zmeň hlasitost hry během hraní:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Přepni mód celé obrazovky:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Vyfoť obrazovku:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Přepni popisky nad ježky:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Osa</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Nahoru)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Dolů)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Klobouček</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Vlevo)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Vpravo)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Tlačítko</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Klávesnice</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Myš: Levé tlačítko</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Myš: Prostřední tlačítko</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Myš: Pravé tlačítko</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Myš: Kolečko nahoru</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Myš: Kolečko dolů</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulátor</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished">Návrat</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mezerník</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation type="unfinished">Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation type="unfinished">Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation type="unfinished">Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation type="unfinished">Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation type="unfinished">Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation type="unfinished">Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation type="unfinished">Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation type="unfinished">Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation type="unfinished">Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation type="unfinished">Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation type="unfinished">Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation type="unfinished">Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation type="unfinished">Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation type="unfinished">Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation type="unfinished">Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished">Enter</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation type="unfinished">Rovná se</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Nahoru</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Dolu</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished">Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished">Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished">Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished">Page down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation type="unfinished">Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation type="unfinished">Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation type="unfinished">Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Pravý shift</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Levý shift</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation type="unfinished">Pravý ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation type="unfinished">Levý ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Pravý alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Levý alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation type="unfinished">Pravá meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation type="unfinished">Levá meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
